CachedVerificationState

Enum CachedVerificationState 

pub enum CachedVerificationState {
    NotVerified,
    OnlySemantic(HardFork),
    ValidAtHashAndHF {
        block_hash: [u8; 32],
        hf: HardFork,
    },
    ValidAtHashAndHFWithTimeBasedLock {
        block_hash: [u8; 32],
        hf: HardFork,
        time_lock: Timelock,
    },
}
Represents if a transaction has been fully validated and under what conditions the transaction is valid in the future.

Variants



NotVerified

The transaction has not been validated.



OnlySemantic(HardFork)

The transaction was only validated semantically.



ValidAtHashAndHF

The transaction is valid* if the block represented by this hash is in the blockchain and the HardFork is the same.

*V1 transactions require checks on their ring-length even if this hash is in the blockchain.

Fields

block_hash: [u8; 32]

The block hash that was in the chain when this transaction was validated.

hf: HardFork

The hf this transaction was validated against.



ValidAtHashAndHFWithTimeBasedLock

The transaction is valid* if the block represented by this hash is in the blockchain and this given time lock is unlocked. The time lock here will represent the youngest used time based lock (If the transaction uses any time based time locks). This is because time locks are not monotonic so unlocked outputs could become re-locked.

*V1 transactions require checks on their ring-length even if this hash is in the blockchain.

Fields

block_hash: [u8; 32]

The block hash that was in the chain when this transaction was validated.

hf: HardFork

The hf this transaction was validated against.

time_lock: Timelock

The youngest used time based lock.

Implementations