pub struct AltBlockInformation {
pub block: Block,
pub block_blob: Vec<u8>,
pub txs: Vec<VerifiedTransactionInformation>,
pub block_hash: [u8; 32],
pub pow_hash: [u8; 32],
pub height: usize,
pub weight: usize,
pub long_term_weight: usize,
pub cumulative_difficulty: u128,
pub chain_id: ChainId,
}Expand description
A block on an alternative chain.
Fields
block: BlockThe block itself.
block_blob: Vec<u8>The serialized byte form of Self::block.
[Block::serialize].
txs: Vec<VerifiedTransactionInformation>All the transactions in the block, excluding the [Block::miner_transaction].
block_hash: [u8; 32]The block’s hash.
[Block::hash].
pow_hash: [u8; 32]The block’s proof-of-work hash.
height: usizeThe block’s height.
weight: usizeThe adjusted block size, in bytes.
long_term_weight: usizeThe long term block weight, which is the weight factored in with previous block weights.
cumulative_difficulty: u128The cumulative difficulty of all blocks up until and including this block.
chain_id: ChainIdThe ChainId of the chain this alt block is on.