pub struct ExtendedBlockHeader {
pub version: HardFork,
pub vote: u8,
pub timestamp: u64,
pub cumulative_difficulty: u128,
pub block_weight: usize,
pub long_term_weight: usize,
}Expand description
Extended header data of a block.
This contains various metadata of a block, but not the block blob itself.
Fields
version: HardForkThe block’s major version.
This is the same value as [monero_oxide::block::BlockHeader::hardfork_version].
vote: u8The block’s hard-fork vote.
This can’t be represented with HardFork as raw-votes can be out of the range of HardForks.
This is the same value as [monero_oxide::block::BlockHeader::hardfork_signal].
timestamp: u64The UNIX time at which the block was mined.
cumulative_difficulty: u128The total amount of coins mined in all blocks so far, including this block’s.
block_weight: usizeThe adjusted block size, in bytes.
long_term_weight: usizeThe long term block weight, based on the median weight of the preceding 100_000 blocks.