pub struct OutputOnChain {
pub height: usize,
pub time_lock: Timelock,
pub key: CompressedPoint,
pub commitment: CompressedPoint,
pub txid: Option<[u8; 32]>,
}Expand description
An already existing transaction output.
Fields
height: usizeThe block height this output belongs to.
time_lock: TimelockThe timelock of this output, if any.
key: CompressedPointThe public key of this output, if any.
commitment: CompressedPointThe output’s commitment.
txid: Option<[u8; 32]>The hash of the transaction hash this output belongs to.
This is None when this field is not requested for in relevant functions.