VerifiedBlockInformation

Struct VerifiedBlockInformation 

pub struct VerifiedBlockInformation {
    pub block: Block,
    pub block_blob: Vec<u8>,
    pub txs: Vec<VerifiedTransactionInformation>,
    pub block_hash: [u8; 32],
    pub pow_hash: [u8; 32],
    pub height: usize,
    pub generated_coins: u64,
    pub weight: usize,
    pub long_term_weight: usize,
    pub cumulative_difficulty: u128,
}
Verified information of a block.

This represents a block that has already been verified to be correct.

Fields

block: Block

The block itself.

block_blob: Vec<u8>

The serialized byte form of Self::block.

[Block::serialize].

txs: Vec<VerifiedTransactionInformation>

All the transactions in the block, excluding the [Block::miner_transaction].

block_hash: [u8; 32]

The block’s hash.

[Block::hash].

pow_hash: [u8; 32]

The block’s proof-of-work hash.

height: usize

The block’s height.

generated_coins: u64

The amount of generated coins (atomic units) in this block.

weight: usize

The adjusted block size, in bytes.

long_term_weight: usize

The long term block weight, which is the weight factored in with previous block weights.

cumulative_difficulty: u128

The cumulative difficulty of all blocks up until and including this block.