pub enum CachedVerificationState {
NotVerified,
OnlySemantic(HardFork),
ValidAtHashAndHF {
block_hash: [u8; 32],
hf: HardFork,
},
ValidAtHashAndHFWithTimeBasedLock {
block_hash: [u8; 32],
hf: HardFork,
time_lock: Timelock,
},
}Expand description
Represents if a transaction has been fully validated and under what conditions the transaction is valid in the future.
Variants
NotVerified
The transaction has not been validated.
OnlySemantic(HardFork)
The transaction was only validated semantically.
ValidAtHashAndHF
The transaction is valid* if the block represented by this hash is in the blockchain and the HardFork
is the same.
*V1 transactions require checks on their ring-length even if this hash is in the blockchain.
Fields
ValidAtHashAndHFWithTimeBasedLock
The transaction is valid* if the block represented by this hash is in the blockchain and this given time lock is unlocked. The time lock here will represent the youngest used time based lock (If the transaction uses any time based time locks). This is because time locks are not monotonic so unlocked outputs could become re-locked.
*V1 transactions require checks on their ring-length even if this hash is in the blockchain.
Implementations
Sourceimpl CachedVerificationState
impl CachedVerificationState
Sourcepub const fn verified_at_block_hash(&self) -> Option<[u8; 32]>
pub const fn verified_at_block_hash(&self) -> Option<[u8; 32]>
Returns the block hash this is valid for if in state CachedVerificationState::ValidAtHashAndHF or CachedVerificationState::ValidAtHashAndHFWithTimeBasedLock.